<?php
/**
* Setup program for phpScheduleIt
*
* This will allow a user with root database privleges to
* automatically set up the required database and its
* tables.  It will also populate any necessary tables.
*
* It uses PEAR::DB to prepare and execute the queries,
* making them database independent.
*
* @author Nick Korbel <lqqkout13@users.sourceforge.net>
* @version 01-07-04
* @package phpScheduleIt
*/
/**
* Base directory of application
*/
@define('BASE_DIR', dirname(__FILE__) . '/..');
/**
* Include PEAR::DB driver file
*/
require_once('DB.php');
/**
* CmnFns class
*/
require_once(BASE_DIR . '/lib/CmnFns.class.php');

session_start();	// Start the session

doPrintHeader();

if (checkConfig()) {

	if (isset($_POST['login'])) {
		setVars();
		doLogin();
	}
	else if (isset($_POST['create'])) {
		$db = dbConnect();
		doCreate();
		doFinish();
	}
	else
		doPrintForm();
}

doPrintFooter();


/**
* Prints html header
* @param none
*/
function doPrintHeader() {
	global $conf;
	echo "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?".">";
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>phpScheduleIt Setup Program</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<link href="../css.css" rel="stylesheet" type="text/css" />
</head>
<body>
<h3 align="center">phpScheduleIt v<?=$conf['app']['version']?></h3>
<?
}


/**
* Print html footer
* @param none
*/
function doPrintFooter() {
?>
</body>
</html>
<?
}


/**
* Prints out login form
* @param none
*/
function doPrintForm() {
	global $conf;
?>
<h3 align="center">Please log into your database</h3>
<form name="login" id="login" method="post" action="<?=$_SERVER['PHP_SELF']?>">
  <table width="60%" border="0" cellspacing="3" cellpadding="0" align="center" style="border: solid 1px #333333; background-color: #fafafa;">
    <tr>
      <td>Enter database root username:</td>
      <td><input type="text" name="user" class="textbox" /></td>
    </tr>
    <tr>
      <td>Enter database root password:</td>
      <td><input type="password" name="password" class="textbox" /></td>
    </tr>
    <tr>
      <td><input type="submit" name="login" value="Login to database" class="button" /></td>
    </tr>
  </table>
  <br />
  <table width="80%" align="center" cellpadding="3" cellspacing="0" border="0" style="font-family: Verdana, Arial; font-size: 12px; background-color: #ffffff; border: solid 1px #DDDDDD">
    <tr>
      <td>
	  <ul>
	  <li>This will set up all the necessary databases and tables for phpScheduleIt.</li>
	  <li>It also populates any required tables.</li>
	  <? if ($conf['db']['drop_old']) echo '<li>Warning: THIS WILL ERASE ALL DATA IN PREVIOUS phpScheduleIt DATABASES!</li>';?>
	  </ul></td>
    </tr>
  </table>
</form>
<?
}

/**
* Checks to make sure necessary fields are set in the config file
* @param none
* @return whether all necessary fields are set
*/
function checkConfig() {
	global $conf;
	switch ($conf['db']['dbType']) {	// Check database type
		case 'mysql' :;
		case 'pgsql' :;
		case 'ibase' :;
		case 'msql' :;
		case 'mssql' :;
		case 'oci8' :;
		case 'odbc' :;
		case 'sybase' :;
		case 'ifx' :;
		case 'fbsql' :;
			break;
		default :
			echo 'Not a valid database type in the config.php file.';
			return false;
			break;
	}

	if (empty($conf['db']['dbUser'])) {		// Check database user
		echo 'Database user is not set in the config.php file.';
		return false;
	}

	if (empty($conf['db']['dbPass'])) {		// Check database password
		echo 'Database user password is not set in the config.php file.';
		return false;
	}

	if (empty($conf['db']['dbName'])) {		// Check database name
		echo 'Database name not set in the config.php file.';
		return false;
	}

	return true;

}

/**
* Verifies that the user entered information and sets up session variables
* @param none
*/
function setVars() {
	$_SESSION['user'] = stripslashes(trim($_POST['user']));
	$_SESSION['password'] = stripslashes(trim($_POST['password']));
}

/**
* Create a connection to the database using user supplied data
* @param none
*/
function doLogin() {
	global $conf;
    // Data Source Name: This is the universal connection string
    // See http://www.pear.php.net/manual/en/package.database.php#package.database.db
    // for more information on DSN
    $dsn = $conf['db']['dbType'] . '://'
			. $_SESSION['user']
			. ':' . $_SESSION['password']
			. '@localhost';

    // Make connection to database
    $db = DB::connect($dsn);

    // If there is an error, print to browser, print to logfile and kill app
    if (DB::isError($db)) {
        die ('Error connecting to database: ' . $db->getMessage() );
    }
	else {
		echo '<h4 align="center">Successfully connected as ' . $_SESSION['user'] . "</h4>\n"
			. "<form name=\"create\" id=\"create\" method=\"post\" action=\"{$_SERVER['PHP_SELF']}\">\n"
			. "<input type=\"submit\" name=\"create\" value=\"Create tables &gt;\" class=\"button\" />\n"
			. "</form>\n";
	}
}

/**
* Create and return a connection to the database
* Requires that setVars() has been called by the user
* loggin in
* @param none
*/
function dbConnect() {
	global $conf;
    // Data Source Name: This is the universal connection string
    // See http://www.pear.php.net/manual/en/package.database.php#package.database.db
    // for more information on DSN
    $dsn = $conf['db']['dbType'] . '://'
			. $_SESSION['user']
			. ':' . $_SESSION['password']
			. '@localhost';

    // Make persistant connection to database
    $db = DB::connect($dsn);

    // If there is an error, print to browser, print to logfile and kill app
    if (DB::isError($db)) {
        die ('Error connecting to database: ' . $db->getMessage() );
    }

    return $db;
}


/**
* Create the database and the tables in it
* - Requires an external file with sql commands
* @param none
*/
function doCreate() {
	global $db;
	global $conf;

	$sqls = array (
					// Create new database
					array ("create database {$conf['db']['dbName']}", 'Creating database'),
					// Select it
					array ("use {$conf['db']['dbName']}", 'Selecting database'),
					// Create login table
					array ("create table login (
  							memberid char(16) not null primary key,
							email char(75) not null,
							password char(32) not null,
							fname char(30) not null,
							lname char(30) not null,
							phone char(16) not null,
							institution char(255),
							position char(100),
							e_add enum('y', 'n') not null default 'y',
							e_mod enum('y', 'n') not null default 'y',
							e_del enum('y', 'n') not null default 'y',
							e_html enum('y', 'n') not null default 'y'
							)", 'Creating login table'),
					// Create login indexes
					array ('create index login_memberid on login (memberid)', 'Creating index'),
					array ('create index login_email on login (email)', 'Creating index'),
					array ('create index login_password on login (password)', 'Creating index'),
					// Create reservations table
					array ('create table reservations (
							resid char(16) not null primary key,
							machid char(16) not null,
							memberid char(16) not null,
							date integer not null,
							startTime integer not null,
							endTime integer not null,
							created integer not null,
							modified integer,
							parentid char(16)
							)', 'Creating reservations table'),
					// Create reservations indexes
					array ('create index res_resid on reservations (resid)', 'Creating index'),
					array ('create index res_machid on reservations (machid)', 'Creating index'),
					array ('create index res_memberid on reservations (memberid)', 'Creating index'),
					array ('create index res_date on reservations (date)', 'Creating index'),
					array ('create index res_startTime on reservations (startTime)', 'Creating index'),
					array ('create index res_endTime on reservations (endTime)', 'Creating index'),
					array ('create index res_created on reservations (created)', 'Creating index'),
					array ('create index res_modified on reservations (modified)', 'Creating index'),
					array ('create index res_parentid on reservations (parentid)', 'Creating index'),
					// Create resources table
					array ("create table resources (
							  machid char(16) not null primary key,
							  name char(75) not null,
							  location char(250),
							  rphone char(16),
							  notes text,
							  status enum('a','i') not null default 'a',
							  minRes integer not null,
							  maxRes integer not null
							  )", 'Creating resources table'),
					// Create resources indexes
					array ('create index rs_machid on resources (machid)', 'Creating index'),
					array ('create index rs_name on resources (name)', 'Creating index'),
					array ('create index rs_status on resources (status)', 'Creating index'),
					// Create permission table
					array ('create table permission (
							  memberid char(16) not null,
							  machid char(16) not null,
							  primary key(memberid, machid)
							  )', 'Creating permission table'),
					// Create permission indexes
					array ('create index per_memberid on permission (memberid)', 'Creating index'),
					array ('create index per_machid on permission (machid)', 'Creating index'),
					// Create database user/permission
					array ("grant select, insert, update, delete
							on {$conf['db']['dbName']}.*
							to {$conf['db']['dbUser']}@localhost identified by '{$conf['db']['dbPass']}'", 'Creating database user')
				);

	if ($conf['db']['drop_old'])	// Drop any old database with same name
		array_unshift($sqls, array ("drop database if exists {$conf['db']['dbName']}", 'Dropping database'));

	foreach ($sqls as $sql) {
		echo $sql[1] . '...';
		$result = $db->query($sql[0]);
		check_result($result);
	}
}

/**
* Examine result and print success or failure message to browswer
* @param PEAR::DB $result pear::db result object
*/
function check_result($result) {
	if (DB::isError($result))
		echo '<span style=\"color: #FF0000; font-weight: bold;\">Failed: </span>' . $result->getMessage() . "</span><br/><br/>\n";
	else
		echo "<span style=\"color: #00CD00;\">Success</span><br/><br/>\n";
}

function doFinish() {
	?>
	Congratulations! You have finished setting up phpScheduleIt and are ready to begin
	using it.<br /><br />
	Please be sure to COMPLETELY REMOVE THE 'install' DIRECTORY.  This is critical, for it contains
	database passwords and other sensitive information.  Failing to do so leaves the door wide open
	for anyone to break into your database!
	<br /><br />
	Thank you for using phpScheduleIt!
<?
}
?>