<?php
/**
* ScheduleDB class
* @author Nick Korbel <lqqkout13@users.sourceforge.net>
* @version 11-08-03
* @package DBEngine
*/
/**
* Base directory of application
*/
@define('BASE_DIR', dirname(__FILE__) . '/../..');
/**
* DBEngine class
*/
require_once(BASE_DIR . '/lib/DBEngine.class.php');

/**
* Provide all database access/manipulation functionality
* @see DBEngine
*/
class ScheduleDB extends DBEngine {
	
	/**
	* Get all reservation data
	* This function gets all reservation data
	* between a given start and end date
	* @param string $firstDay beginning date to return reservations from
	* @param string $lastDay beginning date to return reservations from
	* @return array of reservation data formatted: $array[date|machid][#] = array of data
	*  or an empty array
	*/
	function get_all_res($start, $end) {
		$return = array();
		
		$sql = 'SELECT res.*, rs.name FROM ' . $this->get_table('reservations') . ' as res, ' . $this->get_table('resources') . ' as rs'
			. ' WHERE res.date>=?'
			. ' AND res.date<=?'
			. ' AND res.machid=rs.machid '
			. ' ORDER BY res.date, rs.name, res.startTime, res.endTime';
		$values = array($start, $end);

		$p = $this->db->prepare($sql);
		$result = $this->db->execute($p, $values);
		
		$this->check_for_error($result);
		
		while ($rs = $result->fetchRow()) {
			$index = $rs['date'] . '|' . $rs['machid'];
			$return[$index][] = $rs;
		}
		
		$result->free();
		
		return $return;
	}
}
?>